<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1">
<context>
    <name>ClipGrab</name>
    <message>
        <location filename="clipgrab.cpp" line="37"/>
        <source>Automatic language recognition</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="clipgrab.cpp" line="514"/>
        <source>Downloading update … %1/%2 MBytes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="clipgrab.cpp" line="523"/>
        <source>There was an error while downloading the update.: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="clipgrab.cpp" line="537"/>
        <source>The fingerprint of the downloaded update file could not be verified: %1 should have been %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="clipgrab.cpp" line="549"/>
        <source>Could not open update file.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LoginDialog</name>
    <message>
        <location filename="login_dialog.ui" line="20"/>
        <source>Confirmation or Login Required</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login_dialog.ui" line="54"/>
        <source>Confirmation or login required</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login_dialog.ui" line="67"/>
        <source>This video requires you to sign in or confirm your access before downloading it.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login_dialog.ui" line="93"/>
        <source>Remember login</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.cpp" line="253"/>
        <source>Select Target</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="333"/>
        <source>Please wait while ClipGrab is loading information about the video ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="350"/>
        <source>Please enter the link to the video you want to download in the field below.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="355"/>
        <source>The link you have entered seems to not be recognised by any of the supported portals.&lt;br/&gt;Now ClipGrab will check if it can download a video from that site anyway.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="402"/>
        <source>No downloadable video could be found.&lt;br /&gt;Maybe you have entered the wrong link or there is a problem with your connection.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="415"/>
        <source>ClipGrab - Select target path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="460"/>
        <source>ClipGrab: Video discovered in your clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="460"/>
        <source>ClipGrab has discovered the address of a compatible video in your clipboard. Click on this message to download it now.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="566"/>
        <source>ClipGrab - Exit confirmation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="566"/>
        <source>There is still at least one download in progress.&lt;br /&gt;If you exit the program now, all downloads will be canceled and cannot be recovered later.&lt;br /&gt;Do you really want to quit ClipGrab now?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="603"/>
        <source>Download finished</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="603"/>
        <source>Downloading and converting “%title” is now finished.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="607"/>
        <source>All downloads finished</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="607"/>
        <source>ClipGrab has finished downloading and converting all selected videos.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="672"/>
        <location filename="mainwindow.cpp" line="674"/>
        <location filename="mainwindow.cpp" line="681"/>
        <location filename="mainwindow.cpp" line="683"/>
        <source>ClipGrab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="672"/>
        <location filename="mainwindow.cpp" line="674"/>
        <source> MiB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="674"/>
        <source> KiB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="681"/>
        <location filename="mainwindow.cpp" line="683"/>
        <source>Currently no downloads in progress.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="684"/>
        <source>ClipGrab - Download and Convert Online Videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="846"/>
        <source>No results found.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="913"/>
        <source>&amp;Open downloaded file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="914"/>
        <source>Open &amp;target folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="916"/>
        <source>&amp;Pause download</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="917"/>
        <source>&amp;Restart download</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="918"/>
        <source>&amp;Cancel download</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="920"/>
        <source>Copy &amp;video link</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="921"/>
        <source>Open video link in &amp;browser</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="926"/>
        <source>Resume download</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="936"/>
        <source>Show in &amp;Finder</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindowClass</name>
    <message>
        <location filename="mainwindow.ui" line="14"/>
        <source>ClipGrab - Download and Convert Online Videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="152"/>
        <source>Search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="171"/>
        <source>Enter keywords in the box below in order to search videos on YouTube</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="189"/>
        <source>Downloads</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="198"/>
        <source>Grab this clip!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="227"/>
        <source>Quality:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="243"/>
        <source>Please enter the link to the video you want to download in the field below.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="278"/>
        <source>Format:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="317"/>
        <source>Current Downloads:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="327"/>
        <source>Cancel selected download</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="337"/>
        <source>Open the target folder of the selected download</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="357"/>
        <source>Portal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="362"/>
        <source>Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="367"/>
        <source>Format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="372"/>
        <source>Progress</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="383"/>
        <source>Pause selected download</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="395"/>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="408"/>
        <source>General</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="432"/>
        <source>Here you can adjust some general settings concerning the behaviour of ClipGrab.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="443"/>
        <source>Target Path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="449"/>
        <source>Always save at the last used path.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="463"/>
        <source>Here you can configure where the downloaded videos are to be saved.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="470"/>
        <source>Browse ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="477"/>
        <source>Never ask for file name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="498"/>
        <source>Metadata</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="504"/>
        <source>Here you can configure if ClipGrab is supposed to add metadata (ID3 tags) to your mp3 files.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="511"/>
        <source>Use metadata</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="532"/>
        <source>Clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="538"/>
        <source>Here you can configure how ClipGrab behaves when a downloadable video is discovered in your clipboard.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="545"/>
        <source>Always download</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="552"/>
        <source>Never download</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="559"/>
        <source>Always ask</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="580"/>
        <source>Notifications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="586"/>
        <source>After each download</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="593"/>
        <source>After all downloads have been completed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="613"/>
        <source>Here you can configure when ClipGrab is supposed to display notifications.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="620"/>
        <source>Never</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="628"/>
        <source>Proxy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="634"/>
        <source>Use a proxy server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="644"/>
        <source>Proxy settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="653"/>
        <source>Hostname/IP:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="660"/>
        <source>Port:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="687"/>
        <source>Proxy type:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="695"/>
        <source>HTTP Proxy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="700"/>
        <source>Socks5 Proxy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="727"/>
        <source>Proxy authentication</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="733"/>
        <source>Username:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="750"/>
        <source>Password:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="763"/>
        <source>Proxy requires authentication</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="771"/>
        <source>Other</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="798"/>
        <source>Remove finished downloads from list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="777"/>
        <source>Minimize ClipGrab to the system tray</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="784"/>
        <source>Use WebM if possible</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="791"/>
        <source>Ignore SSL errors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="818"/>
        <source>Remember logins</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="825"/>
        <source>Remember video quality</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="837"/>
        <source>Language</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="861"/>
        <source>Here you can change the language of ClipGrab.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="868"/>
        <source>Please select a language from the list below. You have to restart ClipGrab in order to apply you selection.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="905"/>
        <source>Conversion</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="928"/>
        <source>Experts can create custom presets for the video conversion here.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="935"/>
        <source>Format preset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="945"/>
        <source>Add new preset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="952"/>
        <source>Remove selected preset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="975"/>
        <source>Audio</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="987"/>
        <location filename="mainwindow.ui" line="1039"/>
        <source>Codec</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1013"/>
        <location filename="mainwindow.ui" line="1101"/>
        <source>Bitrate (kb/s)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1020"/>
        <source>Disable Audio</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1030"/>
        <source>Video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1052"/>
        <source>Frames/second</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1111"/>
        <source>Disable video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1126"/>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1132"/>
        <source>&lt;h2&gt;Support ClipGrab!&lt;/h2&gt;
&lt;p&gt;Only with your support, ClipGrab can remain free software!&lt;br&gt;So if you like ClipGrab and also want to help ensuring its further development, please consider making a donation.&lt;/p&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1175"/>
        <source>&lt;h2&gt;Translation&lt;/h2&gt;
ClipGrab is already available in many languages. If ClipGrab has not been translated into your language yet and if you want to contribute a translation, please check &lt;a href=&quot;http://clipgrab.de/translate&quot;&gt;http://clipgrab.de/translate&lt;/a&gt; for further information.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1192"/>
        <source>&lt;h2&gt;Thanks&lt;/h2&gt;
ClipGrab relies on the work of the Qt project and the ffmpeg team.&lt;br&gt;
Visit &lt;a href=&quot;https://www.qt.io&quot;&gt;qt.io&lt;/a&gt; and &lt;a href=&quot;https://ffmpeg.org&quot;&gt;ffmpeg.org&lt;/a&gt; for further information.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MetadataDialog</name>
    <message>
        <location filename="metadata-dialog.ui" line="14"/>
        <source>ClipGrab - enter metadata</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="metadata-dialog.ui" line="25"/>
        <source>Please enter the metadata for your download. If you don&apos;t want to add metadata, just leave the fields empty.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="metadata-dialog.ui" line="45"/>
        <source>Title:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="metadata-dialog.ui" line="52"/>
        <source>Artist:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UpdateMessage</name>
    <message>
        <location filename="update_message.ui" line="14"/>
        <source>Update for ClipGrab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="update_message.ui" line="116"/>
        <source>ClipGrab %1 is now available (you are using %2). Would you like to install the update?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="update_message.ui" line="130"/>
        <source>There is an update for your version of ClipGrab!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="update_message.ui" line="64"/>
        <source>Skip this update</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="update_message.ui" line="91"/>
        <source>Download update</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="update_message.ui" line="240"/>
        <source>about:blank</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="update_message.ui" line="74"/>
        <source>Remind me later</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="update_message.ui" line="41"/>
        <source>The update will begin in just a moment …</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>converter_copy</name>
    <message>
        <location filename="converter_copy.cpp" line="28"/>
        <source>Original</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>converter_ffmpeg</name>
    <message>
        <location filename="converter_ffmpeg.cpp" line="212"/>
        <source>MPEG4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="converter_ffmpeg.cpp" line="213"/>
        <source>WMV (Windows)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="converter_ffmpeg.cpp" line="214"/>
        <source>OGG Theora</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="converter_ffmpeg.cpp" line="215"/>
        <source>MP3 (audio only)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="converter_ffmpeg.cpp" line="216"/>
        <source>OGG Vorbis (audio only)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="converter_ffmpeg.cpp" line="217"/>
        <source>Original (audio only)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="converter_ffmpeg.cpp" line="345"/>
        <source>No installed version of avconv or ffmpeg coud be found. Converting files and downloading 1080p videos from YouTube is not supported.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="converter_ffmpeg.cpp" line="360"/>
        <source>The installed version of %1 is outdated.
Downloading 1080p videos from YouTube is not supported.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>messageDialog</name>
    <message>
        <location filename="message_dialog.ui" line="14"/>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="message_dialog.ui" line="48"/>
        <source>Close this message</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="message_dialog.ui" line="71"/>
        <source>about:blank</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>video</name>
    <message>
        <location filename="video.cpp" line="157"/>
        <location filename="video.cpp" line="303"/>
        <source>Converting ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="video.cpp" line="198"/>
        <source>Downloading ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="video.cpp" line="198"/>
        <source> MiB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="video.cpp" line="368"/>
        <source>Finished</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="video.cpp" line="374"/>
        <source>Finished!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="video.cpp" line="513"/>
        <source>Cancelled</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>video_dailymotion</name>
    <message>
        <location filename="video_dailymotion.cpp" line="73"/>
        <source>HD (1080p)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="video_dailymotion.cpp" line="74"/>
        <source>HD (720p)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="video_dailymotion.cpp" line="75"/>
        <source>480p</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="video_dailymotion.cpp" line="76"/>
        <source>380p</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="video_dailymotion.cpp" line="77"/>
        <source>240p</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>video_facebook</name>
    <message>
        <location filename="video_facebook.cpp" line="161"/>
        <location filename="video_facebook.cpp" line="162"/>
        <location filename="video_facebook.cpp" line="191"/>
        <source>HD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="video_facebook.cpp" line="163"/>
        <location filename="video_facebook.cpp" line="164"/>
        <source>normal</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>video_heuristic</name>
    <message>
        <location filename="video_heuristic.cpp" line="75"/>
        <location filename="video_heuristic.cpp" line="88"/>
        <location filename="video_heuristic.cpp" line="100"/>
        <location filename="video_heuristic.cpp" line="113"/>
        <location filename="video_heuristic.cpp" line="128"/>
        <location filename="video_heuristic.cpp" line="142"/>
        <location filename="video_heuristic.cpp" line="155"/>
        <location filename="video_heuristic.cpp" line="168"/>
        <location filename="video_heuristic.cpp" line="182"/>
        <source>normal</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>video_myspass</name>
    <message>
        <location filename="video_myspass.cpp" line="87"/>
        <source>high</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>video_youtube</name>
    <message>
        <location filename="video_youtube.cpp" line="144"/>
        <source>HD (1080p)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="video_youtube.cpp" line="148"/>
        <source>HD (1440p)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="video_youtube.cpp" line="152"/>
        <source>4K (2160p)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="video_youtube.cpp" line="156"/>
        <source>5K (2880p)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="video_youtube.cpp" line="160"/>
        <source>8K (4320p)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="video_youtube.cpp" line="163"/>
        <source>8K (4320p60)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="video_youtube.cpp" line="481"/>
        <location filename="video_youtube.cpp" line="512"/>
        <location filename="video_youtube.cpp" line="611"/>
        <location filename="video_youtube.cpp" line="614"/>
        <source>Original</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="video_youtube.cpp" line="663"/>
        <source>normal</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
